==> opennms-config-tester-1.10.5-sources.jar: org/opennms/netmgt/config/tester/ConfigTesterDataSource.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2011 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2011 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.config.tester;

import java.io.PrintWriter;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import javax.sql.DataSource;

class ConfigTesterDataSource implements DataSource {

	private List<SQLException> m_connectionGetAttempts = new ArrayList<SQLException>();

	public PrintWriter getLogWriter() throws SQLException {
		return null;
	}

	public int getLoginTimeout() throws SQLException {
		return 0;
	}

	public void setLogWriter(PrintWriter arg0) throws SQLException {
	}

	public void setLoginTimeout(int arg0) throws SQLException {
	}

	public boolean isWrapperFor(Class<?> arg0) throws SQLException {
		return false;
	}

	public <T> T unwrap(Class<T> arg0) throws SQLException {
		return null;
	}

	public Connection getConnection() throws SQLException {
		return createStoreAndThrowException();
	}

	public Connection getConnection(String arg0, String arg1)
			throws SQLException {
		return createStoreAndThrowException();
	}

	private Connection createStoreAndThrowException() throws SQLException {
		SQLException e = createException();
		m_connectionGetAttempts.add(e);
		throw e;
	}

	private SQLException createException() {
		return new SQLException("No database connections should be requested when reading a configuration file, dude.");
	}
	
	public List<SQLException> getConnectionGetAttempts() {
		return m_connectionGetAttempts;
	}
}

==> opennms-config-tester-1.12.1-sources.jar: org/opennms/netmgt/config/tester/ConfigTesterDataSource.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2011-2012 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.config.tester;

import java.io.PrintWriter;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.SQLFeatureNotSupportedException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

import javax.sql.DataSource;

class ConfigTesterDataSource implements DataSource {

	private List<SQLException> m_connectionGetAttempts = new ArrayList<SQLException>();

	public PrintWriter getLogWriter() throws SQLException {
		return null;
	}

	public int getLoginTimeout() throws SQLException {
		return 0;
	}

	public void setLogWriter(PrintWriter arg0) throws SQLException {
	}

	public void setLoginTimeout(int arg0) throws SQLException {
	}

	public Logger getParentLogger() throws SQLFeatureNotSupportedException {
		throw new SQLFeatureNotSupportedException("getParentLogger not supported");
	}

	public boolean isWrapperFor(Class<?> arg0) throws SQLException {
		return false;
	}

	public <T> T unwrap(Class<T> arg0) throws SQLException {
		return null;
	}

	public Connection getConnection() throws SQLException {
		return createStoreAndThrowException();
	}

	public Connection getConnection(String arg0, String arg1)
			throws SQLException {
		return createStoreAndThrowException();
	}

	private Connection createStoreAndThrowException() throws SQLException {
		SQLException e = createException();
		m_connectionGetAttempts.add(e);
		throw e;
	}

	private SQLException createException() {
		return new SQLException("No database connections should be requested when reading a configuration file, dude.");
	}
	
	public List<SQLException> getConnectionGetAttempts() {
		return m_connectionGetAttempts;
	}
}
